from django.shortcuts import render_to_response
from django.views.decorators.cache import never_cache

from waffle import flag_is_active
from waffle.models import Flag, Switch


@never_cache
def wafflejs(request):
    flags = Flag.objects.all()
    flag_values = [(f.name, flag_is_active(request, f.name)) for f in flags]
    switches = Switch.objects.all()
    switch_values = [(s.name, s.active) for s in switches]
    return render_to_response('waffle/waffle.js', {'flags': flag_values,
                                                   'switches': switch_values},
                              mimetype='application/x-javascript')



from jingo import register
import jinja2

from waffle import flag_is_active, switch_is_active


@register.function
@jinja2.contextfunction
def waffle_flag(context, flag_name):
    return flag_is_active(context['request'], flag_name)


@register.function
def waffle_switch(switch_name):
    return switch_is_active(switch_name)
